@@ -89,95 +89,95 @@ SOFTWARE.
 #define InitialTableSize 100
 
 typedef struct _Node {
-    struct _Node   *left,   *right;
+    struct _Node *left, *right;
     Atom a;
     unsigned int fingerPrint;
-    char   *string;
+    char *string;
 } NodeRec, *NodePtr;
 
 #define BAD_RESOURCE 0xe0000000
 
 static Atom lastAtom = None;
-static NodePtr atomRoot = (NodePtr)NULL;
+static NodePtr atomRoot = (NodePtr) NULL;
 static unsigned long tableLength;
 static NodePtr *nodeTable;
 
 static Atom
-_XkbMakeAtom(char *string,unsigned len,Bool makeit)
+_XkbMakeAtom(const char *string, unsigned len, Bool makeit)
 {
-    register    NodePtr * np;
+    register NodePtr *np;
     unsigned i;
-    int     comp;
-    register unsigned int   fp = 0;
+    int comp;
+    register unsigned int fp = 0;
 
     np = &atomRoot;
-    for (i = 0; i < (len+1)/2; i++)
-    {
-	fp = fp * 27 + string[i];
-	fp = fp * 27 + string[len - 1 - i];
+    for (i = 0; i < (len + 1) / 2; i++) {
+        fp = fp * 27 + string[i];
+        fp = fp * 27 + string[len - 1 - i];
     }
-    while (*np != (NodePtr) NULL)
-    {
-	if (fp < (*np)->fingerPrint)
-	    np = &((*np)->left);
-	else if (fp > (*np)->fingerPrint)
-	    np = &((*np)->right);
-	else
-	{			       /* now start testing the strings */
-	    comp = strncmp(string, (*np)->string, (int)len);
-	    if ((comp < 0) || ((comp == 0) && (len < strlen((*np)->string))))
-		np = &((*np)->left);
-	    else if (comp > 0)
-		np = &((*np)->right);
-	    else
-		return(*np)->a;
-	    }
+    while (*np != (NodePtr) NULL) {
+        if (fp < (*np)->fingerPrint)
+            np = &((*np)->left);
+        else if (fp > (*np)->fingerPrint)
+            np = &((*np)->right);
+        else {                  /* now start testing the strings */
+            comp = strncmp(string, (*np)->string, (int) len);
+            if ((comp < 0) || ((comp == 0) && (len < strlen((*np)->string))))
+                np = &((*np)->left);
+            else if (comp > 0)
+                np = &((*np)->right);
+            else
+                return (*np)->a;
+        }
     }
-    if (makeit)
-    {
-	register NodePtr nd;
+    if (makeit) {
+        register NodePtr nd;
 
-	nd = (NodePtr) _XkbAlloc(sizeof(NodeRec));
-	if (!nd)
-	    return BAD_RESOURCE;
-	nd->string = (char *) _XkbAlloc(len + 1);
-	if (!nd->string) {
-	    _XkbFree(nd);
-	    return BAD_RESOURCE;
-	}
-	strncpy(nd->string, string, (int)len);
-	nd->string[len] = 0;
-	if ((lastAtom + 1) >= tableLength) {
-	    NodePtr *table;
+        nd = (NodePtr) _XkbAlloc(sizeof(NodeRec));
+        if (!nd)
+            return BAD_RESOURCE;
+        nd->string = (char *) _XkbAlloc(len + 1);
+        if (!nd->string) {
+            _XkbFree(nd);
+            return BAD_RESOURCE;
+        }
+        strncpy(nd->string, string, (int) len);
+        nd->string[len] = 0;
+        if ((lastAtom + 1) >= tableLength) {
+            NodePtr *table;
 
-	    table = (NodePtr *) _XkbRealloc(nodeTable,
-					 tableLength * (2 * sizeof(NodePtr)));
-	    if (!table) {
-		if (nd->string != string)
-		    _XkbFree(nd->string);
-		_XkbFree(nd);
-		return BAD_RESOURCE;
-	    }
-	    tableLength <<= 1;
-	    nodeTable = table;
-	}
-	*np = nd;
-	nd->left = nd->right = (NodePtr) NULL;
-	nd->fingerPrint = fp;
-	nd->a = (++lastAtom);
-	*(nodeTable+lastAtom) = nd;
-	return nd->a;
+            table = (NodePtr *) _XkbRealloc(nodeTable,
+                                            tableLength * (2 *
+                                                           sizeof(NodePtr)));
+            if (!table) {
+                if (nd->string != string)
+                    _XkbFree(nd->string);
+                _XkbFree(nd);
+                return BAD_RESOURCE;
+            }
+            tableLength <<= 1;
+            nodeTable = table;
+        }
+        *np = nd;
+        nd->left = nd->right = (NodePtr) NULL;
+        nd->fingerPrint = fp;
+        nd->a = (++lastAtom);
+        *(nodeTable + lastAtom) = nd;
+        return nd->a;
     }
     else
-	return None;
+        return None;
 }
 
 static char *
 _XkbNameForAtom(Atom atom)
 {
     NodePtr node;
-    if (atom > lastAtom) return NULL;
-    if ((node = nodeTable[atom]) == (NodePtr)NULL) return NULL;
+
+    if (atom > lastAtom)
+        return NULL;
+    if ((node = nodeTable[atom]) == (NodePtr) NULL)
+        return NULL;
     return strdup(node->string);
 }
 
@@ -185,46 +185,46 @@ static void
 _XkbInitAtoms(void)
 {
     tableLength = InitialTableSize;
-    nodeTable = (NodePtr *)_XkbAlloc(InitialTableSize*sizeof(NodePtr));
-    nodeTable[None] = (NodePtr)NULL;
+    nodeTable = (NodePtr *) _XkbAlloc(InitialTableSize * sizeof(NodePtr));
+    nodeTable[None] = (NodePtr) NULL;
 }
 
 /***====================================================================***/
 
 char *
-XkbAtomGetString(Display *dpy,Atom atm)
+XkbAtomGetString(Display *dpy, Atom atm)
 {
-    if (atm==None)
-	return NULL;
-    if (dpy==NULL)
-	return _XkbNameForAtom(atm);
-    return XGetAtomName(dpy,atm);
+    if (atm == None)
+        return NULL;
+    if (dpy == NULL)
+        return _XkbNameForAtom(atm);
+    return XGetAtomName(dpy, atm);
 }
 
 /***====================================================================***/
 
 Atom
-XkbInternAtom(Display *dpy,char *name,Bool onlyIfExists)
+XkbInternAtom(Display *dpy, const char *name, Bool onlyIfExists)
 {
-    if (name==NULL)
-	return None;
-    if (dpy==NULL) {
-	return _XkbMakeAtom(name, strlen(name), (!onlyIfExists));
+    if (name == NULL)
+        return None;
+    if (dpy == NULL) {
+        return _XkbMakeAtom(name, strlen(name), (!onlyIfExists));
     }
-    return XInternAtom(dpy,name,onlyIfExists);
+    return XInternAtom(dpy, name, onlyIfExists);
 }
 
 /***====================================================================***/
 
 Atom
-XkbChangeAtomDisplay(Display *oldDpy,Display *newDpy,Atom atm)
+XkbChangeAtomDisplay(Display *oldDpy, Display *newDpy, Atom atm)
 {
-char *tmp;
+    char *tmp;
 
-    if (atm!=None) {
-	tmp= XkbAtomGetString(oldDpy,atm);
-	if (tmp!=NULL)
-	    return XkbInternAtom(newDpy,tmp,False);
+    if (atm != None) {
+        tmp = XkbAtomGetString(oldDpy, atm);
+        if (tmp != NULL)
+            return XkbInternAtom(newDpy, tmp, False);
     }
     return None;
 }
@@ -234,10 +234,11 @@ char *tmp;
 void
 XkbInitAtoms(Display *dpy)
 {
-static int been_here= 0;
-    if ((dpy==NULL)&&(!been_here)) {
-	_XkbInitAtoms();
-	been_here= 1;
+    static int been_here = 0;
+
+    if ((dpy == NULL) && (!been_here)) {
+        _XkbInitAtoms();
+        been_here = 1;
     }
     return;
 }
